@@ -135,7 +135,9 @@ class API(object):
 
         link = self.domain + 'TradesRequest'
         response = requests.get(link, headers = {'TOKEN': f'{self.token}'})
-
+        if type(response.json()) != list:
+            print('Request live trades faild')
+            return False
         return response.json()
 
     def account_info(self):
@@ -185,7 +187,13 @@ class API(object):
         Parameters: 
         symbol: target symbol
         '''
-        return json.loads(self.price[symbol].recv())
+        try:
+            result = self.price[symbol].recv()
+        except:
+            self.price[symbol] = websocket.create_connection(self.domain_ws + symbol,header={'TOKEN': self.token})
+            result = self.price[symbol].recv()
+
+        return json.loads(result)
     
     def server_time(self):
         '''
